@@ -37,10 +37,6 @@ class List(Storm):
     # pylint: disable-msg=E0102
     """
     An archived mailing-list.
-
-    Not strictly necessary yet since the list name is used in the email table,
-    but at some point we'll want to store more information on lists in the
-    database.
     """
 
     __storm_table__ = "list"
@@ -92,6 +88,7 @@ class Email(Storm):
     full_email = Reference((list_name, message_id),
                      ("EmailFull.list_name", "EmailFull.message_id"))
     full = Proxy(full_email, "EmailFull.full")
+    mlist = Reference(list_name, "List.name")
 
     def __init__(self, list_name, message_id):
         self.list_name = unicode(list_name)
@@ -149,6 +146,7 @@ class Thread(Storm):
     list_name = Unicode()
     thread_id = Unicode()
     date_active = DateTime()
+    category_id = Int()
     emails = ReferenceSet(
                 (list_name, thread_id),
                 (Email.list_name, Email.thread_id),
@@ -159,6 +157,7 @@ class Thread(Storm):
                 (Email.list_name, Email.thread_id),
                 order_by=Email.thread_order
              )
+    category_obj = Reference(category_id, "Category.id")
     _starting_email = None
 
     def __init__(self, list_name, thread_id, date_active=None):
@@ -216,6 +215,27 @@ class Thread(Storm):
     def __len__(self):
         return self.emails.count()
 
+    def replies_after(self, date):
+        return self.emails.find(Email.date > date)
+
+    def _get_category(self):
+        if not self.category_id:
+            return None
+        return self.category_obj.name
+    def _set_category(self, name):
+        if not name:
+            self.category_id = None
+            return
+        # XXX: this is VERY hackish
+        store = self.__storm_object_info__["store"]
+        category = store.find(Category, Category.name == name).one()
+        if category is None:
+            category = Category(name)
+            store.add(category)
+            store.flush()
+        self.category_id = category.id
+    category = property(_get_category, _set_category)
+
     def __storm_pre_flush__(self):
         """Auto-set the active date from the last email in thread"""
         if self.date_active is not None:
@@ -226,3 +246,18 @@ class Thread(Storm):
             self.date_active = email_dates[0]
         else:
             self.date_active = datetime.datetime.now()
+
+
+class Category(Storm):
+    """
+    A thread category
+    """
+
+    __storm_table__ = "category"
+
+    id = Int(primary=True)
+    name = Unicode()
+    threads = ReferenceSet(id, Thread.category_id)
+
+    def __init__(self, name):
+        self.name = unicode(name)
