@@ -20,7 +20,7 @@ from email.utils import unquote
 from zope.interface import implements
 from mailman.interfaces.messages import IMessageStore
 from storm.locals import Desc
-from storm.expr import And, Or
+from storm.expr import And, Or, Count, Alias
 from dateutil.tz import tzutc
 
 from kittystore import MessageNotFound
@@ -30,7 +30,7 @@ from kittystore.scrub import Scrubber
 from kittystore.utils import get_ref_and_thread_id
 from kittystore.analysis import compute_thread_order_and_depth
 
-from .model import List, Email, Attachment, Thread, EmailFull
+from .model import List, Email, Attachment, Thread, EmailFull, Category
 
 
 class StormStore(object):
@@ -40,7 +40,7 @@ class StormStore(object):
 
     implements(IMessageStore)
 
-    def __init__(self, db, debug=False):
+    def __init__(self, db, search_index=None, debug=False):
         """ Constructor.
         Create the session using the engine defined in the url.
 
@@ -49,6 +49,8 @@ class StormStore(object):
         """
         self.db = db
         self.debug = debug
+        self.search_index = search_index
+
 
     # IMessageStore methods
 
@@ -120,11 +122,11 @@ class StormStore(object):
         msg_date = parsedate(message.get("Date"))
         if msg_date is None:
             # Absent or unparseable date
-            msg_date = datetime.datetime.now()
+            msg_date = datetime.datetime.utcnow()
+        utcoffset = msg_date.utcoffset()
         if msg_date.tzinfo is not None:
             msg_date = msg_date.astimezone(tzutc()).replace(tzinfo=None)
         email.date = msg_date
-        utcoffset = msg_date.utcoffset()
         if utcoffset is None:
             email.timezone = 0
         else:
@@ -158,8 +160,23 @@ class StormStore(object):
         for attachment in attachments:
             self.add_attachment(list_name, msg_id, *attachment)
         self.flush()
+        # search indexing
+        if self.search_index is not None:
+            self.search_index.add(email)
         return email.message_id_hash
 
+    def attach_to_thread(self, email, thread):
+        """Attach an email to an existing thread"""
+        if email.date <= thread.starting_email.date:
+            raise ValueError("Can't attach emails older than the first "
+                             "email in a thread")
+        email.thread_id = thread.thread_id
+        email.in_reply_to = thread.starting_email.message_id
+        if email.date > thread.date_active:
+            thread.date_active = email.date
+        compute_thread_order_and_depth(thread)
+        self.flush()
+
     def delete_message(self, message_id):
         """Remove the given message from the store.
 
@@ -247,6 +264,30 @@ class StormStore(object):
                 )).one()
         return msg
 
+    def search(self, query, list_name=None, page=None, limit=10,
+               sortedby=None, reverse=False):
+        """ Returns a list of email containing the specified keyword in
+        their content.
+
+        :param query: the query string to execute.
+        :param list_name: name of the mailing list in which this email
+            should be searched. If None or not specified, all lists are
+            searched.
+        :param page: the page number to return. If None, don't paginate.
+        :param limit: the number of results per page.
+        :param sortedby: the field to sort by. If None or not specified, sort
+            by match score.
+        :param reverse: reverse the order of the results.
+        """
+        if list_name is not None:
+            query += " list_name:%s" % list_name
+        results = self.search_index.search(
+                query, page, limit, sortedby=sortedby, reverse=reverse)
+        results["results"] = [ self.get_message_by_id_from_list(
+                                    r["list_name"], r["message_id"])
+                               for r in results["results"] ]
+        return results
+
     def search_list_for_content(self, list_name, keyword):
         """ Returns a list of email containing the specified keyword in
         their content.
@@ -438,6 +479,18 @@ class StormStore(object):
             prev_thread = None
         return (prev_thread, next_thread)
 
+    def delete_thread(self, list_name, thread_id):
+        """ Delete the specified thread.
+
+        :param list_name: The name of the mailing list containing this thread
+        :param thread_id: The thread_id as used in the web-pages. Used here to
+            uniquely identify the thread in the database.
+        """
+        self.db.find(Thread, And(
+                Thread.list_name == unicode(list_name),
+                Thread.thread_id == unicode(thread_id)
+                )).remove()
+
     def get_list(self, list_name):
         """ Return the list object for a mailing list name.
 
@@ -458,6 +511,37 @@ class StormStore(object):
                     )[num:num+1].one()
         return result
 
+    def get_top_participants(self, list_name, start, end, limit=None):
+        """ Return all the participants between two given dates.
+
+        :param list_name: The name of the mailing list in which this email
+            should be searched.
+        :param start: A datetime object representing the starting date of
+            the interval to query.
+        :param end: A datetime object representing the ending date of
+            the interval to query.
+        :param limit: Limit the number of participants to return. If None or
+            not supplied, return them all.
+        :returns: The list of thread-starting messages.
+        """
+        number = Alias(Count(Email.sender_email), "number")
+        part = self.db.find(
+                (Email.sender_name, Email.sender_email, number),
+                And(
+                    Email.list_name == unicode(list_name),
+                    Email.date >= start,
+                    Email.date < end,
+                )).group_by(Email.sender_email, Email.sender_name).order_by(Desc(number))
+        if limit is not None:
+            part = part.config(limit=limit)
+        return list(part)
+
+
+    def get_categories(self):
+        """ Return the list of available categories
+        """
+        return list(self.db.find(Category.name).order_by(Category.name))
+
 
     # Attachments
 
